=======
History
=======

0.0.1 (2021-06-22)
------------------

* First release on PyPI.

0.0.2 (2021-06-22)
------------------

* feat: prepare template before signing
* feat: clear linter errors
* chore: version bump and documentation updates regarding installation

0.0.3 (2021-06-23)
------------------

* feat: added the usecase of using the library in python code, added pylint
